import React, { useCallback, useEffect, useState } from "react";
import { CanvasContext } from "./CanvasContext.js";
import { RemoteCoreAPI } from "./RemoteCoreAPI.js";
export const Canvas = (props) => {
    const [isLoading, setIsLoading] = useState(true);
    const [data, setData] = useState(null);
    const [error, setError] = useState(null);
    const [api, setAPI] = useState(null);
    const getApplicationData = useCallback(async (api) => {
        api
            .getApplicationData()
            .then((data) => setData(data))
            .catch((err) => setError(err))
            .finally(() => setIsLoading(false));
    }, []);
    useEffect(() => {
        if (props.host === null) {
            if (api instanceof RemoteCoreAPI) {
                api.close();
                setAPI(null);
            }
            return;
        }
        else if (typeof props.host === "string") {
            if (api instanceof RemoteCoreAPI) {
                if (api.host === props.host) {
                    return;
                }
            }
            const remoteCoreAPI = new RemoteCoreAPI(props.host);
            setAPI(remoteCoreAPI);
            return () => remoteCoreAPI.close();
        }
        else {
            setAPI(props.host);
        }
    }, [props.host]);
    useEffect(() => {
        if (api !== null) {
            getApplicationData(api);
            const listener = () => getApplicationData(api);
            api.addEventListener("update", listener);
            api.addEventListener("connect", listener);
            api.addEventListener("disconnect", listener);
            return () => {
                api.removeEventListener("update", listener);
                api.removeEventListener("connect", listener);
                api.removeEventListener("disconnect", listener);
            };
        }
    }, [api]);
    return React.createElement(CanvasContext.Provider, { value: { isLoading, error, api, data } }, props.children);
};
